==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonWalkingDashedLineArrowRight.md <==
# PersonWalkingDashedLineArrowRight


```text
fontawesome-6/Solid/PersonWalkingDashedLineArrowRight
```

```text
include('fontawesome-6/Solid/PersonWalkingDashedLineArrowRight')
```



| Illustration | PersonWalkingDashedLineArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonWalkingDashedLineArrowRight.png) | ![illustration for PersonWalkingDashedLineArrowRight](../../fontawesome-6/Solid/PersonWalkingDashedLineArrowRight.Local.png) |




## PersonWalkingDashedLineArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingDashedLineArrowRight
include('fontawesome-6/Solid/PersonWalkingDashedLineArrowRight')

' renders the element
PersonWalkingDashedLineArrowRight('PersonWalkingDashedLineArrowRight', 'Person Walking Dashed Line Arrow Right', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingDashedLineArrowRight
include('fontawesome-6/Solid/PersonWalkingDashedLineArrowRight')

' renders the element
PersonWalkingDashedLineArrowRight('PersonWalkingDashedLineArrowRight', 'Person Walking Dashed Line Arrow Right', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonWalkingDashedLineArrowRight.md <==
# PersonWalkingDashedLineArrowRight


```text
fontawesome-6/Solid/PersonWalkingDashedLineArrowRight
```

```text
include('fontawesome-6/Solid/PersonWalkingDashedLineArrowRight')
```



| Illustration | PersonWalkingDashedLineArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonWalkingDashedLineArrowRight.png) | ![illustration for PersonWalkingDashedLineArrowRight](../../fontawesome-6/Solid/PersonWalkingDashedLineArrowRight.Local.png) |




## PersonWalkingDashedLineArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingDashedLineArrowRight
include('fontawesome-6/Solid/PersonWalkingDashedLineArrowRight')

' renders the element
PersonWalkingDashedLineArrowRight('PersonWalkingDashedLineArrowRight', 'Person Walking Dashed Line Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonWalkingDashedLineArrowRight
include('fontawesome-6/Solid/PersonWalkingDashedLineArrowRight')

' renders the element
PersonWalkingDashedLineArrowRight('PersonWalkingDashedLineArrowRight', 'Person Walking Dashed Line Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```
